@@ -164,20 +164,28 @@ def hist(array, xmin, xmax, log, cumul, bins, weights, xlabel, title, fig_name):
     :return: None
     """
     plt.figure(figsize=(8, 6))
+    density = False; edgecolor = 'black'
+    if cumul == True: density = True; edgecolor = None
     plt.hist(
         array,
-        alpha=0.2,
-        color="red",
+        alpha=0.9,
+        color="darkorange",
         edgecolor="black",
         bins=bins,
         range=[xmin, xmax],
         weights=weights,
         log=log,
         cumulative=cumul,
+        density=density
     )
     plt.title(title)
     plt.xlabel(xlabel)
-    plt.ylabel("Frequency")
+    if cumul == False: 
+        plt.ylabel("Frequency") 
+    else:
+        plt.ylabel("Cumulative Probability")
+        plt.ylim([0.0,1.0])
+    plt.xlim([xmin,xmax])
     plt.savefig(fig_name + "." + image_type, dpi=dpi)
     plt.show()
 
@@ -198,22 +206,29 @@ def hist_st(array, xmin, xmax, log, cumul, bins, weights, xlabel, title):
     :param title: title
     :return: None
     """
+    density = False; edgecolor = 'black'
+    if cumul == True: density = True; edgecolor = None
     plt.hist(
         array,
-        alpha=0.2,
-        color="red",
+        alpha=0.9,
+        color="darkorange",
         edgecolor="black",
         bins=bins,
         range=[xmin, xmax],
         weights=weights,
         log=log,
         cumulative=cumul,
+        density=density
     )
     plt.title(title)
     plt.xlabel(xlabel)
-    plt.ylabel("Frequency")
-
-
+    if cumul == False: 
+        plt.ylabel("Frequency") 
+    else:
+        plt.ylabel("Cumulative Probability")
+        plt.ylim([0.0,1.0])
+    plt.xlim([xmin,xmax])
+    
 def locmap(
     df,
     xcol,
